# Generated by Django 5.1.1 on 2024-11-13 10:08

import django.db.models.deletion
import django_bleach.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='SecurityQuestion',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('question', django_bleach.models.BleachField(max_length=150)),
            ],
            options={
                'db_table': 'security_questions',
            },
        ),
        migrations.CreateModel(
            name='SecurityAnswer',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('answer', django_bleach.models.BleachField(max_length=100)),
                ('user', models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='user_security_answers', to=settings.AUTH_USER_MODEL)),
                ('question', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_security_questions.securityquestion', verbose_name='Security Question')),
            ],
            options={
                'db_table': 'security_answer',
                'unique_together': {('user', 'question')},
            },
        ),
    ]
